@@ -1,10 +1,7 @@
 
 
-extern AV *args;
-
 extern int PL_argc;
 extern char **PL_argv;
 
-void boot_args(void);
 void args2argv(void);
 void free_PL_argv(void);
