@@ -19,7 +19,7 @@ int hook_set=0;
 static int my_agc_hook(atom_t a) {
     if(!strcmp(OPAQUE_FUNCTOR, PL_atom_chars(a))) {
         const char *oname;
-        int olen;
+        size_t olen;
 	dTHX;
 	dSP;
 	ENTER;
